@@ -47,6 +47,24 @@ function is_adminer_endpoint() {
     return false;
 }
 
+// Function to check if current request is to filemanager
+function is_filemanager_endpoint() {
+    $script_path = $_SERVER['SCRIPT_FILENAME'];
+    $request_uri = parse_url($_SERVER['REQUEST_URI'], PHP_URL_PATH);
+    
+    // Check if the script is in the filemanager directory
+    if (strpos($script_path, '/docker/whp/web/filemanager/') === 0) {
+        return true;
+    }
+    
+    // Check if the request URI starts with /filemanager/ (exact match)
+    if (strpos($request_uri, '/filemanager/') === 0) {
+        return true;
+    }
+    
+    return false;
+}
+
 // Function to validate CSRF token
 function validate_csrf_token() {
     if ($_SERVER['REQUEST_METHOD'] === 'POST') {
@@ -195,10 +213,10 @@ if (defined('AUTH_USER') && $_SERVER['SCRIPT_FILENAME'] == '/docker/whp/web/inde
     check_page_permission();
 }
 
-// CSRF Protection for all POST requests (except login and Adminer)
+// CSRF Protection for all POST requests (except login, Adminer, and filemanager)
 if (defined('AUTH_USER') && $_SERVER['REQUEST_METHOD'] === 'POST') {
-    // Skip CSRF check for login form and Adminer
-    if (!isset($_POST['user']) && !isset($_POST['password']) && !is_adminer_endpoint()) {
+    // Skip CSRF check for login form, Adminer, and filemanager
+    if (!isset($_POST['user']) && !isset($_POST['password']) && !is_adminer_endpoint() && !is_filemanager_endpoint()) {
         if (!validate_csrf_token()) {
             if (is_api_endpoint()) {
                 header('HTTP/1.1 403 Forbidden');
